@@ -1,4 +1,3 @@
-import logging
 import typing
 from dataclasses import dataclass
 from typing import Any, Callable, Dict, TypeVar
@@ -8,11 +7,14 @@ from google.protobuf.json_format import MessageToDict
 
 import flytekit
 from flytekit import ExecutionParameters, FlyteContextManager, PythonFunctionTask, kwtypes
-from flytekit.extend import ExecutionState, IgnoreOutputs, Interface, PythonTask, SerializationSettings, TaskPlugins
-from flytekit.models.sagemaker import training_job as _training_job_models
+from flytekit.configuration import SerializationSettings
+from flytekit.extend import ExecutionState, IgnoreOutputs, Interface, PythonTask, TaskPlugins
+from flytekit.loggers import logger
 from flytekit.types.directory.types import FlyteDirectory
 from flytekit.types.file import FlyteFile
 
+from .models import training_job as _training_job_models
+
 
 @dataclass
 class SagemakerTrainingJobConfig(object):
@@ -151,7 +153,7 @@ class SagemakerCustomTrainingTask(PythonFunctionTask[SagemakerTrainingJobConfig]
         if the number of execution instances is > 1. Otherwise this is considered to be a single node execution
         """
         if self._is_distributed():
-            logging.info("Distributed context detected!")
+            logger.info("Distributed context detected!")
             exec_state = FlyteContextManager.current_context().execution_state
             if exec_state and exec_state.mode == ExecutionState.Mode.TASK_EXECUTION:
                 """
@@ -175,10 +177,10 @@ class SagemakerCustomTrainingTask(PythonFunctionTask[SagemakerTrainingJobConfig]
         return a None
         """
         if self._is_distributed():
-            logging.info("Distributed context detected!")
+            logger.info("Distributed context detected!")
             dctx = flytekit.current_context().distributed_training_context
             if not self.task_config.should_persist_output(dctx):
-                logging.info("output persistence predicate not met, Flytekit will ignore outputs")
+                logger.info("output persistence predicate not met, Flytekit will ignore outputs")
                 raise IgnoreOutputs(f"Distributed context - Persistence predicate not met. Ignoring outputs - {dctx}")
         return rval
 
